#!/usr/bin/env python
from setuptools import setup, find_packages

setup(
    name='jargon',
    namespace_packages=['jargon'],
    version='0.1',
    description='jargon',
    long_description='jargon',
    classifiers=[],
    author='Jargon',
    author_email='info@jargon.io',
    url='',
    keywords='',
    packages=find_packages(),
    zip_safe=False,
)
